@@ -3,6 +3,9 @@
 
 capture.output({  ## stops printing outputs on assigning in log
 
+  if (!identical(Sys.getenv("NOT_CRAN"), "true")) return()
+  skip_on_cran()
+
 ## Accepts data.frame
 test_that("calc_rate.bg works using default inputs", {
   ## Analyses all columns by default
