@@ -7,6 +7,9 @@
 
 capture.output({  ## stops printing outputs on assigning
 
+  if (!identical(Sys.getenv("NOT_CRAN"), "true")) return()
+  skip_on_cran()
+
   # Create testing objects --------------------------------------------------
   {
     insp.ft_obj <- inspect.ft(flowthrough.rd, delta.oxy = 4, plot = FALSE)
@@ -213,17 +216,114 @@ capture.output({  ## stops printing outputs on assigning
                                  oxy.unit = "mL/L", flowrate.unit = "l/s",
                                  output.unit = "mg/h/mm2", area = 2, mass = NULL,
                                  S = NULL, t = NULL, P = NULL),
-                 "convert_DO: Input or output units require Salinity input")
+                 "convert_rate.ft: Input or output units require Salinity input")
     expect_error(convert_rate.ft(-1.4,
                                  oxy.unit = "mL/L", flowrate.unit = "l/s",
                                  output.unit = "mg/h/mm2", area = 2, mass = NULL,
                                  S = 35, t = NULL, P = NULL),
-                 "convert_DO: Input or output units require Temperature input")
+                 "convert_rate.ft: Input or output units require Temperature input")
     expect_message(convert_rate.ft(-1.4,
                                    oxy.unit = "mL/L", flowrate.unit = "l/s",
                                    output.unit = "mg/h/mm2", area = 2, mass = NULL,
                                    S = 35, t = 15, P = NULL),
-                   "convert_DO: Input or output units require Atmospheric Pressure input")
+                   "convert_rate.ft: Input or output units require Atmospheric Pressure input")
+  })
+
+  test_that("convert_rate.ft - stops if S, t, and P are vectors", {
+
+    expect_error(convert_rate.ft(-0.0001534657, oxy.unit = "mL/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429,
+                                 S = 35:36,
+                                 t= 12,
+                                 P = 1.01),
+                 "convert_rate.ft: The 'S' input should be a single value.")
+    expect_error(convert_rate.ft(-0.0001534657, oxy.unit = "mL/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429,
+                                 S = 35,
+                                 t= 12:13,
+                                 P = 1.01),
+                 "convert_rate.ft: The 't' input should be a single value.")
+    expect_error(convert_rate.ft(-0.0001534657, oxy.unit = "mL/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429,
+                                 S = 35,
+                                 t= 12,
+                                 P = c(1,1.01)),
+                 "convert_rate.ft: The 'P' input should be a single value.")
+
+  })
+
+  test_that("convert_rate.ft - correct S, t, and P values saved to summary", {
+
+    # single rate value
+    expect_equal(convert_rate.ft(-0.0001534657, oxy.unit = "mL/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429,
+                                 S = 35,
+                                 t= 12,
+                                 P = 1.01)$summary$S,
+                 35)
+    # multiple rate values
+    expect_equal(convert_rate.ft(c(-0.001, -0.002), oxy.unit = "mL/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429,
+                                 S = 35,
+                                 t= 12,
+                                 P = 1.01)$summary$S,
+                 c(35,35))
+    # single rate value
+    expect_equal(convert_rate.ft(-0.0001534657, oxy.unit = "mL/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429,
+                                 S = 35,
+                                 t= 12,
+                                 P = 1.01)$summary$t,
+                 12)
+    # multiple rate values
+    expect_equal(convert_rate.ft(c(-0.001, -0.002), oxy.unit = "mL/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429,
+                                 S = 35,
+                                 t= 12,
+                                 P = 1.01)$summary$t,
+                 c(12,12))
+    # single rate value
+    expect_equal(convert_rate.ft(-0.0001534657, oxy.unit = "mL/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429,
+                                 S = 35,
+                                 t= 12,
+                                 P = 1.01)$summary$P,
+                 1.01)
+    # multiple rate values
+    expect_equal(convert_rate.ft(c(-0.001, -0.002), oxy.unit = "mL/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429,
+                                 S = 35,
+                                 t= 12,
+                                 P = 1.01)$summary$P,
+                 c(1.01,1.01))
+    # NA when NULL
+    expect_equal(convert_rate.ft(-0.0001534657, oxy.unit = "mg/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429)$summary$S,
+                 NA)
+    expect_equal(convert_rate.ft(-0.0001534657, oxy.unit = "mg/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429)$summary$t,
+                 NA)
+    # Default value for P
+    expect_equal(convert_rate.ft(-0.0001534657, oxy.unit = "mg/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429)$summary$P,
+                 1.013253)
+    # multiple rate values
+    expect_equal(convert_rate.ft(c(-0.001, -0.002), oxy.unit = "mg/L", time.unit = "s", output.unit = "mg/h/mm2",
+                                 flowrate.unit = "l/m",
+                                 area = 0.000001429)$summary$S,
+                 c(NA,NA))
   })
 
 
@@ -601,9 +701,9 @@ capture.output({  ## stops printing outputs on assigning
 
   test_that("convert_rate.ft - plot is produced with converted calc_rate.ft objects", {
     expect_output(conv.adjft.1 <- convert_rate.ft(adjft.1, oxy.unit = "mg/l", flowrate.unit = "L/m",
-                                    output.unit = "mg/h",
-                                    mass = NULL, area = NULL,
-                                    S=S, t=t, P=P, plot = TRUE))
+                                                  output.unit = "mg/h",
+                                                  mass = NULL, area = NULL,
+                                                  S=S, t=t, P=P, plot = TRUE))
     expect_output(plot(conv.adjft.many.ms))
     expect_output(plot(conv.adjft.many.ms, type = "full"))
     expect_output(plot(conv.adjft.many.ms, type = "rate"))
