@@ -8,6 +8,9 @@
 
 capture.output({  ## stops printing console outputs on assigning
 
+  if (!identical(Sys.getenv("NOT_CRAN"), "true")) return()
+  skip_on_cran()
+
   # Create multicolumn dfs for testing --------------------------------------
 
   {
